@@ -1,2 +1,2 @@
 from .corpus import KoreanChatCorpus
-from .runner import Runner
+from .task import GenerationTask
